---
header1: header content 1
header2: header content 2
header3: header content 3
header4: header content 4
---

# {Insert title Here}

# 0. MD Header 0

<!-- sample link (https://www.somelink.com) -->

new line <br/>
new line <br />
<br>

| Col1        | Col2        | Col3        | Col4 | Col5 |
| ----------- | ----------- | ----------- | ---- | ---- |
| content 2.1 | content 2.2 | content 2.3 |      |      |

# 1. MD Header 1 Subsections

## 1.1 MD Subheader 1.1

some text

> blockquote text

<!--
some text inside html block
# IgnoreIt A
and one more line
-->

## 1.2 MD Subheader 1.2

some text 2

```
# IgnoreIt B
while True:
    print('Hello World!')
    for i in range(0, 1):
        time.sleep(10)

system.exit()
```

and some text again

## 1.3 MD Subheader 1.3 HTML

some text 3

### 1.3.1 Valid header <!-- ### some comment here -->

<details open>
  <summary>## This is the sample summary</summary>
  <p>And here are the details:</p>
  <ol>
    <li>Item 1</li>
    <li>Item 2</li>
    <li># Not a header</li>
  </ol>
</details>

<kbd> # some command # </kbd>

some text <kbd><kbd># Nested</kbd>#nested text<kbd>nested</kbd></kbd>

### 1.3.2 Header with <kbd>some text</kbd>

<samp>Some text that should be ignored here
this too

# IgnoreIt C

</samp>

X<sub>i</sub> + Y <sup>i</sup> = Z<sup>i</sup><sub>i</sub>

<ins> # not supported header </ins> <del># deleted text</del>
<del> # not supported header </del>

<ins> #ignore

## ignore

### ignore

# IgnoreIt D

</ins>

some text <var> # some variable </var>

<q> some quote # with fake header </q>

<dl> # Ignore list
# ignore
  <dt># item</dt>
  <dd>## subitem</dd>
  <dt>#item</dt>
  <dd>##subitem</dd>
</dl>

<div itemscope itemtype ="">
  <h3 itemprop="name"># Ignore this</h3>
  <span>A: <span itemprop="a">the text</span> (c)</span>
  <span itemprop="aa">text</span>
  <a href="https://www.ibm.com" itemprop="bb">BB</a>
</div>

\<ctag # not a header> s </ctag>

\< this however will not

### 1.3.3 Valid header

> blockquote here

### 1.3.4 Valid header <this is okay>

## 1.4 MD subheader 1.4 Empty

# 2. MD Header 2 Blockquotes

> Some blockquote text here
> And another blockquote

some text after blockquote

# 3. MD Header 3 Empty

# 4. MD Header 4 Tricky headers

<!--
## this is not a proper header - abc
## this is not a proper header 2 - ignore
## this is also not a header - ignore this
# IgnoreIt E
-->

## 4.1 This is a proper subsection

some text
abc
defg

## 4.2 Another proper subsection with tricky headers

<!--
## this is not a proper header - abc
## this is not a proper header 2 - ignore
## this is also not a header - ignore this
# IgnoreIt F
# this as well
### and this
-->

some text again

# 5.Deep Section with no spacing

some text lvl 1

## 5.1 A section 1

### 5.1.1 A deeper section 1

#### 5.1.1.1 A even deeper section 1

some deep text

##### 5.1.1.1.1 Stop here 1

some very deep text

## 5.2 A section 2

### 5.2.1 A deeper section 2

some deep text

> some deep blockquote

### 5.2.2 Another deeper section 2

#### 5.2.2.1 A even deeper section here 2

```
def very_deep_code():
    do_something()
```

### 5.2.3 And another deeper section 2

some text here

<!--
# ignore me
## ignore me too
### me too
# IgnoreIt G
-->

## 5.3 A section 3

# 6. Next section empty

| Col1        | Col2        | Col3        |
| ----------- | ----------- | ----------- |
| content 6.1 | content 6.2 | content 6.3 |
